#ifndef _ELM_ACTIONSLIDER_PART_EO_H_
#define _ELM_ACTIONSLIDER_PART_EO_H_

#ifndef _ELM_ACTIONSLIDER_PART_EO_CLASS_TYPE
#define _ELM_ACTIONSLIDER_PART_EO_CLASS_TYPE

typedef Eo Elm_Actionslider_Part;

#endif

#ifndef _ELM_ACTIONSLIDER_PART_EO_TYPES
#define _ELM_ACTIONSLIDER_PART_EO_TYPES


#endif
#ifdef EFL_BETA_API_SUPPORT
/** Elementary Actionslider internal part class
 *
 * @ingroup Elm_Actionslider_Part
 */
#define ELM_ACTIONSLIDER_PART_CLASS elm_actionslider_part_class_get()

EWAPI const Efl_Class *elm_actionslider_part_class_get(void) EINA_CONST;
#endif /* EFL_BETA_API_SUPPORT */

#endif
